-- About WorldCatLocalSearch.lua
--
-- WorldCatLocalSearch.lua does a WorldCatLocal search.  It provides buttons to do searches based on title, isxn or oclc number.
-- It can also do an automatic search using a search priority string, in which case it will use the first field listed in the string that has a value.
-- The valid fields are title, isxn and oclc.
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.
--
-- "f" is the formname on google.com
-- "q" is the text box name on google.com

local autoSearch = GetSetting("AutoSearch");

local interfaceMngr = nil;
local browser = nil;

function Init()
	interfaceMngr = GetInterfaceManager();
	
	-- Create browser
	browser = interfaceMngr:CreateBrowser("WorldCat Local Search", "WorldCat Local Search", "Script");
	
	-- Create buttons
	local button = browser:CreateButton("Search Title", GetClientImage("Search32"), "SearchTitle", "WorldCat Local");
	if (CanSearchTitle() ~= true) then
		button.BarButton.Enabled = false;
	end
	
	button = browser:CreateButton("Search ISXN", GetClientImage("Search32"), "SearchISXN", "WorldCat Local");
	if (CanSearchISXN() ~= true) then
		button.BarButton.Enabled = false;
	end
	
	button = browser:CreateButton("Search OCLC", GetClientImage("Search32"), "SearchOCLC", "WorldCat Local");
	if (CanSearchOCLC() ~= true) then
		button.BarButton.Enabled = false;
	end
	
	browser:Show();
	
	if autoSearch then
		AutoSearch();
	end
end

function CanSearchTitle()
	return GetTitle() ~= "";
end

function CanSearchOCLC()
	local value = GetFieldValue("Transaction", "ESPNumber")
	if (value ~= nil and value ~= "") then
		return true;
	end
	
	return false;
end

function CanSearchISXN()
	local value = GetFieldValue("Transaction", "ISSN")
	if (value ~= nil and value ~= "") then
		return true;
	end
	
	return false;
end

function GetTitle()
	local title;
	if	(GetFieldValue("Transaction", "RequestType") == "Article") then
		title = GetFieldValue("Transaction", "PhotoArticleTitle");
	else
		title = GetFieldValue("Transaction", "LoanTitle");
	end
	
	if (title == nil) then
		title = "";
	end

	return title;
end

function AutoSearch()
	local priorities = strsplit(",", GetSetting("SearchPriority"));
	
	for index, priority in ipairs(priorities) do
		local priorityLower = priority:lower();
		
		if (priorityLower == "title" and CanSearchTitle()) then
			SearchTitle();
			return;
		elseif (priorityLower == "oclc" and CanSearchOCLC()) then
			SearchOCLC();
			return;
		elseif (priorityLower == "isxn" and CanSearchISXN()) then
			SearchISXN();
			return;
		end		
	end
	
	browser:Navigate(GetSetting("WorldCatURL"));
end

function SearchTitle()
	Search("ti:"..GetTitle());
end

function SearchISXN()
	local value = GetFieldValue("Transaction", "ISSN");
	
	if (value == nil) then
		value = "";
	end
	
	local prefix;
	
	if (GetFieldValue("Transaction", "RequestType") == "Article") then
		prefix = "n2:";
	else
		prefix ="bn";
	end
	
	Search(prefix..value);
end

function SearchOCLC()
	local value = GetFieldValue("Transaction", "ESPNumber");
	
	if	(value == nil) then
		value = "";
	end
	
	Search("no:"..value);
end

function Search(searchTerm)
	browser:Navigate(GetSetting("WorldCatURL").."/search?qt=wc_org_uwashington&scope=0&oldscope=&wcsbtn2w=Search&q="..searchTerm);
end

function strsplit(delimiter, text)
  local list = {};
  local pos = 1;
  if string.find("", delimiter, 1) then -- this would result in endless loops
    error("delimiter matches empty string!");
  end
  
  while 1 do
    local first,last = string.find(text, delimiter, pos);
    if first then -- found?
      table.insert(list, string.sub(text, pos, first-1));
      pos = last+1;
    else
      table.insert(list, string.sub(text, pos));
      break;
    end
  end
  
  return list;
end


	



